@@ -1,6 +1,5 @@
 /* Prolog main program for the PPL/YAP-Prolog predicate checker.
    Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-   Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -19,11 +18,10 @@ along with this program; if not, write to the Free Software Foundation,
 Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
-site: http://bugseng.com/products/ppl/ . */
+site: http://www.cs.unipr.it/ppl/ . */
 
 :- ensure_loaded('ppl_yap.pl').
 :- ensure_loaded('ppl_prolog_generated_test_main.pl').
-:- use_module(library(lists), [append/3, member/2]).
 
 prolog_system('YAP').
 
