@@ -2,7 +2,6 @@
 % for testing the Parma Polyhedra Library and its Prolog interface.
 %
 % Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
-% Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)
 %
 % This file is part of the Parma Polyhedra Library (PPL).
 %
@@ -21,7 +20,7 @@
 % Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 %
 % For the most up-to-date information see the Parma Polyhedra Library
-% site: http://bugseng.com/products/ppl/ .
+% site: http://www.cs.unipr.it/ppl/ .
 
 % Object-level clauses are stored as user_clause(Head, Body) facts.
 :- dynamic(user_clause/2).
@@ -795,7 +794,6 @@ POSSIBILITY OF SUCH DAMAGES.\n').
 common_main :-
   write('\
 Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>\n\
-Copyright (C) 2010-2012 BUGSENG srl (http://bugseng.com)\n\
 this program is free software, covered by the GNU General Public License,\n\
 and you are welcome to change it and/or distribute copies of it\n\
 under certain conditions.\n\
