@@ -1,5 +1,5 @@
 /* Test that the right exceptions are thrown in case of incorrect uses.
-   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -299,10 +299,10 @@ test11() {
   C_Polyhedron ph2(3);
 
   try {
-    // This is an invalid use of function
-    // C_Polyhedron::intersection_assign_and_minimize(ph2): it is illegal
+    // This is an invalid use of method
+    // C_Polyhedron::intersection_assign(ph2): it is illegal
     // to apply this function to two polyhedra of different dimensions.
-    ph1.intersection_assign_and_minimize(ph2);
+    ph1.intersection_assign(ph2);
   }
   catch (std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl << endl;
@@ -322,7 +322,7 @@ test12() {
   try {
     // This is an invalid use of the function
     // C_Polyhedron::intersection_assign(ph2): it is illegal to apply
-    // this function to two polyhedron of different dimensions.
+    // this function to two polyhedra of different dimensions.
     ph1.intersection_assign(ph2);
   }
   catch (std::invalid_argument& e) {
@@ -342,12 +342,12 @@ test13() {
 
   try {
     // This is an invalid use of the function
-    // C_Polyhedron::add_generators_and_minimize(gs): it is illegal
+    // C_Polyhedron::add_generators(gs): it is illegal
     // to add a system of generator that is not dimension-compatible
     // with the polyhedron.
     Generator_System gs;
     gs.insert(point(w));
-    ph.add_generators_and_minimize(gs);
+    ph.add_generators(gs);
   }
   catch (std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl << endl;
@@ -386,12 +386,12 @@ test15() {
 
   try {
     // This is an invalid use of the function
-    // C_Polyhedron::add_constraints_and_minimize(cs): it is illegal to
+    // C_Polyhedron::add_constraints(cs): it is illegal to
     // add a system of constraints that is not dimensional incompatible
     // with the polyhedron.
     Constraint_System cs;
     cs.insert(x - y >= 0);
-    ph.add_constraints_and_minimize(cs);
+    ph.add_constraints(cs);
   }
   catch (std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl << endl;
@@ -744,13 +744,13 @@ test29() {
 
   try {
     // This is an invalid use of the function
-    // C_Polyhedron::add_generators_and_minimize(gs): it is illegal
+    // C_Polyhedron::add_generators(gs): it is illegal
     // to apply this function with a system of generators with no
     // points to an empty polyhedron.
     Generator_System gs;
     gs.insert(line(x));
     gs.insert(line(y));
-    ph.add_generators_and_minimize(gs);
+    ph.add_generators(gs);
   }
   catch (std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl << endl;
@@ -894,10 +894,10 @@ test35() {
 
   try {
     // This is an invalid used of the function
-    // `add_generators_and_minimize(gs)': it is illegal to
+    // `add_generators(gs)': it is illegal to
     // add a system of generators that does not contain points
     // to an empty polyhedron.
-    ph.add_generators_and_minimize(gs);
+    ph.add_generators(gs);
   }
   catch (std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl << endl;
@@ -1353,7 +1353,6 @@ test54() {
   return false;
 }
 
-}
 bool
 test55() {
   Variable y(1);
@@ -1400,7 +1399,9 @@ test56() {
   }
   return false;
 }
- // namespace
+
+} // namespace
+
 BEGIN_MAIN
   DO_TEST(test01);
   DO_TEST(test02);
